<a name="v0.0.1"></a>
## [v0.0.1](https://github.com/socialpoint-labs/unity-yaml-parser/compare/9a1144f82294455e863e9f535edf841aeb847ac1...v0.0.1) (2019-06-11)

### Features
- **scope:** initial commit ([9a1144f](https://github.com/socialpoint-labs/unity-yaml-parser/commit/9a1144f82294455e863e9f535edf841aeb847ac1))


